#!/usr/bin/env python
from DFTB import XYZ

import numpy as np

import sys
import os.path

if __name__ == "__main__":
    if len(sys.argv) < 5:
        print "Usage: %s <initial geometry .xyz> <final geometry .xyz> N <path .xyz>" % os.path.basename(sys.argv[0])
        print "  The cartesian geometries are interpolated linearly between the initial"
        print "  and the final structures using N-2 intermediate points."
        print "  The interpolated geometries are written to <path .xyz>"
        exit(-1)
    xyz0 = sys.argv[1]
    xyz1 = sys.argv[2]
    N = int(sys.argv[3])
    xyz_interp = sys.argv[4]
    # read initial geometry
    atomlist0 = XYZ.read_xyz(xyz0)[0]
    x0 = XYZ.atomlist2vector(atomlist0)
    # read final geometry
    atomlist1 = XYZ.read_xyz(xyz1)[0]
    x1 = XYZ.atomlist2vector(atomlist1)

    rs = np.linspace(0.0, 1.0, N)
    
    geometries_interp = []
    for r in rs:
        xr = x0 + r*(x1-x0)
        geometries_interp.append( XYZ.vector2atomlist(xr, atomlist0) )

    XYZ.write_xyz(xyz_interp, geometries_interp)
    print "Interpolated geometries written to %s" % xyz_interp
